<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Faq;
use Illuminate\Http\Request;
use Carbon\Carbon;


class FaqController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.faq', [
            'faqs' => Faq::all(),
        ]);
    }

    public function faq_add()
    {
        return view('admin.faq_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $request->validate([
            'title' => 'required',
            'full_content' => 'required',
            'show_on_home' => 'required',
        ]);

        Faq::create([
            'title' => $request->title,
            'full_content' => $request->full_content,
            'show_on_home' => $request->show_on_home
        ]);

        return Redirect()->route('admin.faq')->with('success', A_SUCCESS_DATA_ADD);
    }


    public function edit_page($id)
    {
        return view('admin.faq_edit', [
            'faq' => Faq::find($id),
        ]);
    }


    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $request->validate([
            'title' => 'required',
            'full_content' => 'required',
            'show_on_home' => 'required',
        ]);

        $faq = Faq::findOrFail($id);
        $faq->title = $request->title;
        $faq->full_content = $request->full_content;
        $faq->show_on_home = $request->show_on_home;
        $faq->update();

        return Redirect()->route('admin.faq')->with('success', A_SUCCESS_DATA_UPDATE);
    }


    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        Faq::find($id)->forceDelete();
        return Redirect()->route('admin.faq')->with('error', A_SUCCESS_DATA_DELETE);
    }
}
