<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\NewsCategory;
use App\Models\News;
use App\Models\Service;
use Illuminate\Http\Request;
use Carbon\Carbon;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Image;

class NewsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.news', [
            'newss' => News::get(),
        ]);
    }

    public function news_add()
    {
        return view('admin.news_add', [
            'news_categories' => NewsCategory::all(),
        ]);
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $request->validate([
            'title' => 'required|unique:news',
            'slug' => 'unique:news',
            'short_content' => 'required',
            'full_content' => 'required',
            'category_id' => 'required',
        ]);

        if ($request->slug == '') {
            $slug = Str::slug($request->title);
        } else {
            $slug = Str::slug($request->slug);
        }

        $count = News::where('slug', $slug)->count();
        if ($count != 0) {
            return back()->with('error', A_ERROR_SLUG_EXIST);
        }

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            $filename1 = 'news_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
        }

        if ($request->hasFile('banner')) {
            $file = $request->file('banner');
            $ext = $file->getClientOriginalExtension();
            $filename2 = 'news_banner_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename2);
        }

        News::create([
            'title' => $request->title,
            'slug' => $slug,
            'short_content' => $request->short_content,
            'full_content' => $request->full_content,
            'category_id' => $request->category_id,
            'photo' => $filename1,
            'banner' => $filename2,
            'show_comment' => $request->comment,
            'total_view' => 0,
            'meta_title' => $request->meta_title,
            'meta_description' => $request->meta_description
        ]);

        return Redirect()->route('admin.news')->with('success', A_SUCCESS_DATA_ADD);
    }


    public function edit_page($id)
    {
        return view('admin.news_edit', [
            'news' => News::find($id),
            'news_categories' => NewsCategory::all(),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $request->validate([
            'title' => ['required',Rule::unique('news')->ignore($id),],
            'slug' => [Rule::unique('news')->ignore($id),],
            'short_content' => 'required',
            'full_content' => 'required',
            'category_id' => 'required',
        ]);

        if ($request->slug == '') {
            $slug = Str::slug($request->title);
        } else {
            $slug = Str::slug($request->slug);
        }

        $count = News::where('slug', $slug)->where('id', '!=', $id)->count();
        if ($count != 0) {
            return back()->with('error', A_ERROR_SLUG_EXIST);
        }

        $news = News::findOrFail($id);
        if ($request->hasFile('photo')) {
            $request->validate([
                'photo' => 'image'
            ]);
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$news->photo));
            $filename1 = 'news_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
            $news->photo = $filename1;
        }
        if ($request->hasFile('banner')) {
            $request->validate([
                'banner' => 'image'
            ]);
            $file = $request->file('banner');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$news->banner));
            $filename2 = 'news_banner_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename2);
            $news->banner = $filename2;
        }

        $news->title = $request->title;
        $news->slug = $slug;
        $news->short_content = $request->short_content;
        $news->full_content = $request->full_content;
        $news->category_id = $request->category_id;
        $news->show_comment = $request->show_comment;
        $news->meta_title = $request->meta_title;
        $news->meta_description = $request->meta_description;
        $news->update();

        return Redirect()->route('admin.news')->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $photo = News::find($id)->photo;
        unlink(public_path('uploads/' . $photo));
        $banner = News::find($id)->banner;
        unlink(public_path('uploads/' . $banner));
        News::find($id)->forceDelete();
        return Redirect()->route('admin.news')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
