<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\PortfolioCategory;
use App\Models\Portfolio;
use Illuminate\Http\Request;
use Carbon\Carbon;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;


class PortfolioCategoryController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.portfolio_category', [
            'portfolio_categories' => PortfolioCategory::get(),
        ]);
    }

    public function portfolio_category_add()
    {
        return view('admin.portfolio_category_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'name' => 'required|unique:portfolio_categories'
        ]);

        PortfolioCategory::create([
            'name' => $request->name
        ]);
        return Redirect()->route('admin.portfolio_category')->with('success', A_SUCCESS_DATA_ADD);
    }

    public function edit_page($id)
    {
        return view('admin.portfolio_category_edit', [
            'portfolio_category_single' => PortfolioCategory::find($id),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;
        $request->validate([
            'name' => ['required',Rule::unique('portfolio_categories')->ignore($id),]
        ]);
        $obj = PortfolioCategory::findOrFail($id);
        $obj->name = $request->name;
        $obj->update();
        return Redirect()->route('admin.portfolio_category')->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        // Check data if in another table
        $total = Portfolio::where('category_id', $id)->count();
        if($total > 0) {
            return Redirect()->back()->with('error', 'A_ERROR_DATA_NOT_DELETE_FOR_ANOTHER_TABLE');
        }
        PortfolioCategory::find($id)->forceDelete();
        return back()->with('success', A_SUCCESS_DATA_DELETE);
    }
}
